@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2018 Bryan Siepert for Adafruit Industries
 #
-# Copyright (c) 2018 Bryan Siepert for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `MAX31856`
 ====================================================
@@ -39,9 +22,10 @@ Implementation Notes
 **Software and Dependencies:**
 
 * Adafruit CircuitPython firmware for the supported boards:
-  https://github.com/adafruit/circuitpython/releases
+  https://circuitpython.org/downloads
 
 * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
+
 """
 
 from time import sleep
@@ -125,11 +109,37 @@ class ThermocoupleType:  # pylint: disable=too-few-public-methods
 class MAX31856:
     """Driver for the MAX31856 Universal Thermocouple Amplifier
 
-      :param ~busio.SPI spi_bus: The SPI bus the MAX31856 is connected to.
-      :param ~microcontroller.Pin cs: The pin used for the CS signal.
-      :param ~adafruit_max31856.ThermocoupleType thermocouple_type: The type of thermocouple.\
+    :param ~busio.SPI spi: The SPI bus the MAX31856 is connected to.
+    :param ~microcontroller.Pin cs: The pin used for the CS signal.
+    :param ~adafruit_max31856.ThermocoupleType thermocouple_type: The type of thermocouple.\
       Default is Type K.
 
+    **Quickstart: Importing and using the MAX31856**
+
+        Here is an example of using the :class:`MAX31856` class.
+        First you will need to import the libraries to use the sensor
+
+        .. code-block:: python
+
+            import board
+            from digitalio import DigitalInOut, Direction
+            import adafruit_max31856
+
+        Once this is done you can define your `board.SPI` object and define your sensor object
+
+        .. code-block:: python
+
+            spi = board.SPI()
+            cs = digitalio.DigitalInOut(board.D5)  # Chip select of the MAX31856 board.
+            sensor = adafruit_max31856.MAX31856(spi, cs)
+
+
+        Now you have access to the :attr:`temperature` attribute
+
+        .. code-block:: python
+
+            temperature = sensor.temperature
+
     """
 
     # A class level buffer to reduce allocations for reading and writing.
@@ -154,7 +164,7 @@ class MAX31856:
 
     @property
     def temperature(self):
-        """The temperature of the sensor and return its value in degrees celsius. (read-only)"""
+        """The temperature of the sensor and return its value in degrees Celsius. (read-only)"""
         self._perform_one_shot_measurement()
 
         # unpack the 3-byte temperature as 4 bytes
@@ -172,7 +182,7 @@ class MAX31856:
 
     @property
     def reference_temperature(self):
-        """The temperature of the cold junction in degrees celsius. (read-only)"""
+        """The temperature of the cold junction in degrees Celsius. (read-only)"""
         self._perform_one_shot_measurement()
 
         raw_read = unpack(">h", self._read_register(_MAX31856_CJTH_REG, 2))[0]
